# monitor-slim-poller: Lightweight Monitor Poller

This project provides a set of Dockerfiles with Docker-compose for setting up a *Slim Poller*.

Structure
---

```
.
├── images
│   ├── base
│   │   └── centos
│   │      └── Dockerfile
│   │
│   ├── merlin
│   │   ├── Dockerfile
│   │   ├── init.sh
│   │   └── default_config
│   │
│   ├── naemon
│   │   ├── Dockerfile
│   │   ├── init.sh
│   │   └── default_config
│   │
│   └── shared_files
│
├── .env
└── docker-compose.yml (Defines Docker services)
```

IPC
---

The *ipc* volume is used for storing named pipes and unix sockets, shared
between containers in the stack.

Environment
---

The *.env* file has two options:

- `BUILD_ENV` controls whether to use rpms from production repos, `prod`, development repos, `devel` or staging repos, `stage` when building the images. Default is `devel`.
- `DOCKER_HUB_ORG` controls to/from which Docker Hub organization (or user) containers will be pushed/pulled.
- `PUSH_ENV` controls whether to push/pull images to/from development or production repositories in Docker Hub. Set to `devel_` for development and leave empty for production. Default is `devel_` and should not be changed.

Configuration
---

The default configuration for naemon and merlin is found at `images/naemon/default_config` and `images/merlin/default_config` respectively.

The configuration is copied into the container. When the container starts, we check if any configuration files are present, and if not, copy the default configuration to the host volume for persistence.

Please refer to `docker-compose.yml` to see all the configuration volumes needed.

Build
---

```bash
$ docker-compose build
```

Pull
---

If the images have been pushed to Docker Hub.

```bash
$ docker-compose pull
```

Run
---

```bash
$ docker-compose up
```

Supervisor
---

To start Naemon using supervisor use the same commands as above but specify the
`docker-compose-ssh.yml` file as configuration file, like this:

```bash
$ docker-compose -f docker-compose-ssh.yml ...
```

Build and Push images to Docker Hub
---

To push new images to Docker Hub run the GoCD pipeline **slim-poller** in the **Slim-poller** pipeline group. The pipeline runs the `build_and_push.sh` script.

There are some different possible options when pushing images to Docker Hub. Press the **play plus** button and then **Environmental Variables**

- To build images using rpms from *development* repositories, leave `BUILD_ENV` as is. Default is `devel`.
- To build images using rpms from *staging* repositories, set `BUILD_ENV` to `stage`.
- To build images using rpms from *production* repositories, set `BUILD_ENV` to `prod`.
- To push images to *development* repositories in Docker Hub, leave `PUSH_ENV` as is. Default is `devel_`.
- To push images to *production* repositories in Docker Hub, clear `PUSH_ENV` and leave empty.
- To push images with a version tag enter the desired `VERSION_TAG`.
- To push images with the latest tag only, leave `VERSION_TAG` epmty.
- To push SSH images set `COMPOSE_FILE` to `-f docker-compose-ssh.yaml`

When done press **Trigger Pipeline**.

Only changes merged to the master branch will affect the GoCD pipeline.
