#!/bin/sh
#
# Script that is run in a GoCD pipeline with the purpose of pushing the slim
# poller containers to Docker Hub.
#
# Changes in this script needs to be merged to the master branch before changes
# will affect the pipeline in GoCD.
#
# The env variables USERNAME, TOKEN and VERSION_TAG are present in the GoCD
# pipeline.
#

check_exit_status () {
    # If the return value of latest command is non zero
    # print return value and exit the GoCD pipeline with an error
    if [ $1 -ne 0 ]; then
        printf '%s: %d\n%s\n' "### Non zero exist status" $1 "### Exiting..."
        exit 1
    fi
}

# Check if we are building ssh image, if we do, don't build base/merlin images
IMAGE=
if [ "$COMPOSE_FILE" = "-f docker-compose-ssh.yml" ]; then
    IMAGE=naemon-core-ssh
fi

printf '%s\n' "### Log in to Docker Hub"
echo $TOKEN | docker login -u $USERNAME --password-stdin
check_exit_status $?

printf '%s\n' "### Pull the latest CentOS 7 base image"
docker pull centos:7
check_exit_status $?

printf '%s\n' "### Build containers, tag: ${VERSION_TAG:-latest}"
docker-compose $COMPOSE_FILE build $IMAGE
check_exit_status $?

printf '%s\n' "### Push to Docker Hub, tag: ${VERSION_TAG:-latest}"
docker-compose $COMPOSE_FILE push $IMAGE
check_exit_status $?

if [ ! -z "$VERSION_TAG" ]; then
    # VERSION_TAG is set. Thus we have already built the VERSION_TAG:ed image
    # Now we need to unset the variable to also build and push the latest
    # tag:ed image

    unset VERSION_TAG

    printf '%s\n' "### Build containers, tag: ${VERSION_TAG:-latest}"
    docker-compose $COMPOSE_FILE build $IMAGE
    check_exit_status $?

    printf '%s\n' "### Push to Docker Hub, tag: ${VERSION_TAG:-latest}"
    docker-compose $COMPOSE_FILE push $IMAGE
    check_exit_status $?

    printf '%s\n' "### Teardown and clean up, tag: ${VERSION_TAG:-latest}"
    docker-compose $COMPOSE_FILE down -v --rmi all --remove-orphans
    check_exit_status $?

fi

printf '%s\n' "### Teardown and clean up, tag: ${VERSION_TAG:-latest}"
docker-compose $COMPOSE_FILE down -v --rmi all --remove-orphans
check_exit_status $?

printf '%s\n' "### Log out from Docker Hub"
docker logout
check_exit_status $?
