#!/bin/bash
source /usr/libexec/op5-log.sh
set -e

# correct permissions on .ssh
chmod 700 /opt/monitor/.ssh/

# include nss_wrapper code
source /usr/local/bin/nss_wrapper.sh

if [ ! -f /opt/monitor/etc/naemon.cfg ]; then
  op5-log "init" "INFO" "No Naemon config found, copying default config"
  cp -r /usr/local/etc/naemon/default_config/* /opt/monitor/etc
  mkdir /opt/monitor/etc/oconf
fi

# Wait for merlin container to come online, as Naemon requires the socket to be
# available at startup
max_wait_s=60
wait_step_s=5
current_wait=0
while [ ! -e /var/run/naemon/merlin.sock ]
do
  op5-log "init" "INFO" "Waiting for merlin socket..."
  sleep $wait_step_s
  current_wait=$(( $current_wait + $wait_step_s ))
  if [ $current_wait -ge $max_wait_s ]; then
    op5-log "init" "CRITICAL" "Merlin socket did not come up after $current_wait seconds. Exiting"
    exit 1
  fi
done

exec /usr/local/bin/tini -- $@
